@@ -27,6 +27,7 @@
 #include <search.h>
 #include <string.h>
 #include <errno.h>
+#include <sys/apparmor.h>
 
 #include "parser.h"
 #include "profile.h"
@@ -90,7 +91,7 @@ static int add_named_transition(Profile *prof, struct cod_entry *entry)
 	char *name = NULL;
 
 	/* check to see if it is a local transition */
-	if (!entry->ns) {
+	if (!label_contains_ns(entry->nt_name)) {
 		char *sub = strstr(entry->nt_name, "//");
 		/* does the subprofile name match the rule */
 
@@ -117,22 +118,22 @@ static int add_named_transition(Profile *prof, struct cod_entry *entry)
 			}
 			sprintf(name, "%s//%s", prof->name, entry->nt_name);
 			free(entry->nt_name);
-			entry->nt_name = name;
+			entry->nt_name = NULL;
+		} else {
+			/**
+			 * pass control of the memory pointed to by nt_name
+			 * from entry to add_entry_to_x_table()
+			 */
+			name = entry->nt_name;
+			entry->nt_name = NULL;
 		}
-	}
-	if (entry->ns) {
-	  name = (char *) malloc(strlen(entry->ns) + strlen(entry->nt_name) + 3);
-		if (!name) {
-			PERROR("Memory allocation error\n");
-			exit(1);
-		}
-		sprintf(name, ":%s:%s", entry->ns, entry->nt_name);
-		free(entry->ns);
-		free(entry->nt_name);
-		entry->ns = NULL;
-		entry->nt_name = NULL;
 	} else {
+		/**
+		 * pass control of the memory pointed to by nt_name
+		 * from entry to add_entry_to_x_table()
+		 */
 		name = entry->nt_name;
+		entry->nt_name = NULL;
 	}
 
 	return add_entry_to_x_table(prof, name);
@@ -163,8 +164,6 @@ void post_process_file_entries(Profile *prof)
 				mode |= SHIFT_MODE(n << 10, AA_OTHER_SHIFT);
 			entry->mode = ((entry->mode & ~AA_ALL_EXEC_MODIFIERS) |
 				       (mode & AA_ALL_EXEC_MODIFIERS));
-			entry->ns = NULL;
-			entry->nt_name = NULL;
 		}
 		/* FIXME: currently change_profile also implies onexec */
 		cp_mode |= entry->mode & (AA_CHANGE_PROFILE);
@@ -181,7 +180,7 @@ void post_process_file_entries(Profile *prof)
 			PERROR("Memory allocation error\n");
 			exit(1);
 		}
-		new_ent = new_entry(NULL, buffer, AA_MAY_WRITE, NULL);
+		new_ent = new_entry(buffer, AA_MAY_WRITE, NULL);
 		if (!new_ent) {
 			PERROR("Memory allocation error\n");
 			exit(1);
@@ -211,7 +210,7 @@ static int profile_add_hat_rules(Profile *prof)
 		return 0;
 
 	/* add entry to hat */
-	entry = new_entry(NULL, strdup(CHANGEHAT_PATH), AA_MAY_WRITE, NULL);
+	entry = new_entry(strdup(CHANGEHAT_PATH), AA_MAY_WRITE, NULL);
 	if (!entry)
 		return ENOMEM;
 
@@ -220,12 +219,13 @@ static int profile_add_hat_rules(Profile *prof)
 	return 0;
 }
 
-int load_policy_list(ProfileList &list, int option)
+int load_policy_list(ProfileList &list, int option,
+		     aa_kernel_interface *kernel_interface, int cache_fd)
 {
 	int res = 0;
 
 	for (ProfileList::iterator i = list.begin(); i != list.end(); i++) {
-		res = load_profile(option, *i);
+		res = load_profile(option, kernel_interface, *i, cache_fd);
 		if (res != 0)
 			break;
 	}
@@ -233,14 +233,16 @@ int load_policy_list(ProfileList &list, int option)
 	return res;
 }
 
-int load_flattened_hats(Profile *prof, int option)
+int load_flattened_hats(Profile *prof, int option,
+			aa_kernel_interface *kernel_interface, int cache_fd)
 {
-	return load_policy_list(prof->hat_table, option);
+	return load_policy_list(prof->hat_table, option, kernel_interface,
+				cache_fd);
 }
 
-int load_policy(int option)
+int load_policy(int option, aa_kernel_interface *kernel_interface, int cache_fd)
 {
-	return load_policy_list(policy_list, option);
+	return load_policy_list(policy_list, option, kernel_interface, cache_fd);
 }
 
 int load_hats(std::ostringstream &buf, Profile *prof)
