@@ -213,8 +213,13 @@ querytest "QUERY dbus (svc receive)" fail $dbus_svc_query
 genqueryprofile "file,"
 expect allow
 perms file exec,write,read,append,create,delete,setattr,getattr,chmod,chown,link,linksubset,lock,exec_mmap
-querytest "QUERY file (all base perms #1)" xpass /anything
-querytest "QUERY file (all base perms #2)" xpass /everything
+if [ "$(kernel_features query/label/multi_transaction)" == "true" ] ; then
+    querytest "QUERY file (all base perms #1)" pass /anything
+    querytest "QUERY file (all base perms #2)" pass /everything
+else
+    querytest "QUERY file (all base perms #1)" xpass /anything
+    querytest "QUERY file (all base perms #2)" xpass /everything
+fi
 
 genqueryprofile "/etc/passwd r,"
 expect allow
