@@ -10,7 +10,7 @@
 # ------------------------------------------------------------------
 
 import unittest
-from common_test import AATest, setup_all_loops
+from common_test import AATest, setup_all_loops, setup_aa
 from common_test import read_file, write_file
 
 import os
@@ -19,7 +19,7 @@ import sys
 
 import apparmor.aa  # needed to set global vars in some tests
 from apparmor.aa import (check_for_apparmor, get_output, get_reqs, get_interpreter_and_abstraction, create_new_profile,
-     get_profile_flags, set_profile_flags, set_options_audit_mode, is_skippable_file, is_skippable_dir,
+     get_profile_flags, set_profile_flags, set_options_audit_mode, set_options_owner_mode, is_skippable_file, is_skippable_dir,
      parse_profile_start, parse_profile_data, separate_vars, store_list_var, write_header,
      var_transform, serialize_parse_profile_start, get_file_perms, propose_file_rules)
 from apparmor.aare import AARE
@@ -414,6 +414,20 @@ class AaTest_set_options_audit_mode(AATest):
         new_options = set_options_audit_mode(rule_obj, options)
         self.assertEqual(new_options, expected)
 
+class AaTest_set_options_owner_mode(AATest):
+    tests = [
+        ((FileRule.parse('owner /foo/bar r,'),      ['/foo/bar r,', '/foo/* r,', '/** r,']                                  ), ['owner /foo/bar r,', 'owner /foo/* r,', 'owner /** r,']),
+        ((FileRule.parse('owner /foo/bar r,'),      ['/foo/bar r,', 'owner /foo/* r,', 'owner /** r,']                      ), ['owner /foo/bar r,', 'owner /foo/* r,', 'owner /** r,']),
+        ((FileRule.parse('/foo/bar r,'),            ['/foo/bar r,', '/foo/* r,', '/** r,']                                  ), ['/foo/bar r,', '/foo/* r,', '/** r,']),
+        ((FileRule.parse('/foo/bar r,'),            ['owner /foo/bar r,', 'owner /foo/* r,', 'owner /** r,']                ), ['/foo/bar r,', '/foo/* r,', '/** r,']),
+        ((FileRule.parse('audit owner /foo/bar r,'),['audit /foo/bar r,', 'audit /foo/* r,', '#include <abstractions/base>']), ['audit owner /foo/bar r,', 'audit owner /foo/* r,', '#include <abstractions/base>']),
+    ]
+
+    def _run_test(self, params, expected):
+        rule_obj, options = params
+        new_options = set_options_owner_mode(rule_obj, options)
+        self.assertEqual(new_options, expected)
+
 class AaTest_is_skippable_file(AATest):
     def test_not_skippable_01(self):
         self.assertFalse(is_skippable_file('bin.ping'))
@@ -768,7 +782,7 @@ class AaTest_get_file_perms_1(AATest):
         self.profile_dir = '%s/profiles' % self.tmpdir
         shutil.copytree('../../profiles/apparmor.d/', self.profile_dir, symlinks=True)
 
-        profile = apparmor.aa.profile_storage('/test', '/test', 'test-aa.py')
+        profile = apparmor.aa.ProfileStorage('/test', '/test', 'test-aa.py')
 
         # simple profile without any includes
         profile['file'].add(FileRule.parse('owner /usr/share/common-licenses/**  w,'))
@@ -781,11 +795,12 @@ class AaTest_get_file_perms_1(AATest):
 class AaTest_get_file_perms_2(AATest):
     tests = [
         ('/usr/share/common-licenses/foo/bar',      {'allow': {'all': {'r'},            'owner': {'w'}  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/usr/share/common-licenses/**'}              }),
+        ('/usr/share/common-licenses/what/ever',    {'allow': {'all': {'r'},            'owner': {'w'}  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/usr/share/common-licenses/**', '/usr/share/common-licenses/what/ever'}      }),
         ('/dev/null',                               {'allow': {'all': {'r', 'w', 'k'},  'owner': set()  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/dev/null'}                                  }),
         ('/foo/bar',                                {'allow': {'all': {'r', 'w'},       'owner': set()  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/foo/bar'}                                   }),  # exec perms not included
         ('/no/thing',                               {'allow': {'all': set(),            'owner': set()  }, 'deny': {'all':set(),    'owner': set()},    'paths': set()                                          }),
-        ('/usr/lib/ispell/',                        {'allow': {'all': {'r'},            'owner': set()  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/usr/lib/ispell/', '/usr/lib{,32,64}/**'}    }),  # from abstractions/enchant
-        ('/usr/lib/aspell/*.so',                    {'allow': {'all': {'m', 'r'},       'owner': set()  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/usr/lib/aspell/*', '/usr/lib/aspell/*.so', '/usr/lib{,32,64}/**'} }),  # from abstractions/aspell via abstractions/enchant
+        ('/usr/lib/ispell/',                        {'allow': {'all': {'r'},            'owner': set()  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/usr/lib/ispell/', '/{usr/,}lib{,32,64}/**'}    }),  # from abstractions/enchant
+        ('/usr/lib/aspell/*.so',                    {'allow': {'all': {'m', 'r'},       'owner': set()  }, 'deny': {'all':set(),    'owner': set()},    'paths': {'/usr/lib/aspell/*', '/usr/lib/aspell/*.so', '/{usr/,}lib{,32,64}/**'} }),  # from abstractions/aspell via abstractions/enchant
     ]
 
     def _run_test(self, params, expected):
@@ -802,12 +817,13 @@ class AaTest_get_file_perms_2(AATest):
         apparmor.aa.load_include('abstractions/enchant')
         apparmor.aa.load_include('abstractions/aspell')
 
-        profile = apparmor.aa.profile_storage('/test', '/test', 'test-aa.py')
+        profile = apparmor.aa.ProfileStorage('/test', '/test', 'test-aa.py')
         profile['include']['abstractions/base'] = True
         profile['include']['abstractions/bash'] = True
         profile['include']['abstractions/enchant'] = True  # includes abstractions/aspell
 
         profile['file'].add(FileRule.parse('owner /usr/share/common-licenses/**  w,'))
+        profile['file'].add(FileRule.parse('owner /usr/share/common-licenses/what/ever a,'))  # covered by the above 'w' rule, so 'a' should be ignored
         profile['file'].add(FileRule.parse('/dev/null rwk,'))
         profile['file'].add(FileRule.parse('/foo/bar rwix,'))
 
@@ -820,8 +836,9 @@ class AaTest_propose_file_rules(AATest):
         (['/usr/share/common-licenses/foo/bar', 'w'],   ['/usr/share/common*/foo/* rw,', '/usr/share/common-licenses/** rw,', '/usr/share/common-licenses/foo/bar rw,']         ),
         (['/dev/null',                          'wk'],  ['/dev/null rwk,']                                                                                                      ),
         (['/foo/bar',                           'rw'],  ['/foo/bar rw,']                                                                                                        ),
-        (['/usr/lib/ispell/',                   'w'],   ['/usr/lib{,32,64}/** rw,', '/usr/lib/ispell/ rw,']                                                                     ),
-        (['/usr/lib/aspell/some.so',            'k'],   ['/usr/lib/aspell/* mrk,', '/usr/lib/aspell/*.so mrk,', '/usr/lib{,32,64}/** mrk,', '/usr/lib/aspell/some.so mrk,']     ),
+        (['/usr/lib/ispell/',                   'w'],   ['/{usr/,}lib{,32,64}/** rw,', '/usr/lib/ispell/ rw,']                                                                     ),
+        (['/usr/lib/aspell/some.so',            'k'],   ['/usr/lib/aspell/* mrk,', '/usr/lib/aspell/*.so mrk,', '/{usr/,}lib{,32,64}/** mrk,', '/usr/lib/aspell/some.so mrk,']     ),
+        (['/foo/log',                           'w'],   ['/foo/log w,']                                                                                                            ),
     ]
 
     def _run_test(self, params, expected):
@@ -842,7 +859,7 @@ class AaTest_propose_file_rules(AATest):
         apparmor.aa.user_globs['/usr/share/common*/foo/*'] = AARE('/usr/share/common*/foo/*', True)
         apparmor.aa.user_globs['/no/thi*ng'] = AARE('/no/thi*ng', True)
 
-        profile = apparmor.aa.profile_storage('/test', '/test', 'test-aa.py')
+        profile = apparmor.aa.ProfileStorage('/test', '/test', 'test-aa.py')
         profile['include']['abstractions/base'] = True
         profile['include']['abstractions/bash'] = True
         profile['include']['abstractions/enchant'] = True  # includes abstractions/aspell
@@ -850,11 +867,66 @@ class AaTest_propose_file_rules(AATest):
         profile['file'].add(FileRule.parse('owner /usr/share/common-licenses/**  w,'))
         profile['file'].add(FileRule.parse('/dev/null rwk,'))
         profile['file'].add(FileRule.parse('/foo/bar rwix,'))
+        profile['file'].add(FileRule.parse('/foo/log a,'))  # will be replaced with '/foo/log w,' (not 'wa')
 
         rule_obj = FileRule(params[0], params[1], None, FileRule.ALL, owner=False, log_event=True)
         proposals = propose_file_rules(profile, rule_obj)
         self.assertEqual(proposals, expected)
 
+
+class AaTest_propose_file_rules_with_absolute_includes(AATest):
+    tests = [
+        # log event path       and perms    expected proposals
+        (['/not/found/anywhere',    'r'],   ['/not/found/anywhere r,']),
+        (['/dev/null',              'w'],   ['/dev/null rw,']),
+        (['/some/random/include',   'r'],   ['/some/random/include rw,']),
+        (['/some/other/include',    'w'],   ['/some/other/* rw,', '/some/other/inc* rw,', '/some/other/include rw,']),
+    ]
+
+    def _run_test(self, params, expected):
+        self.createTmpdir()
+
+        #copy the local profiles to the test directory
+        self.profile_dir = '%s/profiles' % self.tmpdir
+        shutil.copytree('../../profiles/apparmor.d/', self.profile_dir, symlinks=True)
+
+        # load the abstractions we need in the test
+        apparmor.aa.profiledir = self.profile_dir
+        apparmor.aa.load_include('abstractions/base')
+
+        abs_include1 = write_file(self.tmpdir, 'test-abs1', "/some/random/include rw,")
+        apparmor.aa.load_include(abs_include1)
+
+        abs_include2 = write_file(self.tmpdir, 'test-abs2', "/some/other/* rw,")
+        apparmor.aa.load_include(abs_include2)
+
+        abs_include3 = write_file(self.tmpdir, 'test-abs3', "/some/other/inc* rw,")
+        apparmor.aa.load_include(abs_include3)
+
+        profile = apparmor.aa.ProfileStorage('/test', '/test', 'test-aa.py')
+        profile['include']['abstractions/base'] = False
+        profile['include'][abs_include1] = False
+        profile['include'][abs_include2] = False
+        profile['include'][abs_include3] = False
+
+        rule_obj = FileRule(params[0], params[1], None, FileRule.ALL, owner=False, log_event=True)
+        proposals = propose_file_rules(profile, rule_obj)
+        self.assertEqual(proposals, expected)
+
+
+class AaTest_nonexistent_includes(AATest):
+    def test_bad_includes(self):
+        tests = [
+            "/nonexistent/absolute/path",
+            "nonexistent/relative/path",
+        ]
+
+        for i in tests:
+            with self.assertRaises(AppArmorException):
+                apparmor.aa.load_include(i)
+
+
+setup_aa(apparmor.aa)
 setup_all_loops(__name__)
 if __name__ == '__main__':
     unittest.main(verbosity=2)
